@@ -1,10 +1,10 @@
-from haystack import site, indexes
+from haystack import indexes
 from djinn_announcements.models.announcement import Announcement
 from djinn_announcements.models.serviceannouncement import ServiceAnnouncement
-from pgsearch.base import ContentRealTimeSearchIndex
+from pgsearch.base import ContentSearchIndex
 
 
-class AnnouncementIndex(ContentRealTimeSearchIndex):
+class AnnouncementIndex(ContentSearchIndex):
 
     """ Index for announcements """
 
@@ -12,6 +12,10 @@ class AnnouncementIndex(ContentRealTimeSearchIndex):
 
         return self.model.objects.filter(serviceannouncement__isnull=True)
 
+    def get_model(self):
+
+        return Announcement
+
 
 class ServiceAnnouncementIndex(AnnouncementIndex):
 
@@ -19,6 +23,7 @@ class ServiceAnnouncementIndex(AnnouncementIndex):
 
         return self.model.objects.all()
 
+    def get_model(self):
+
+        return ServiceAnnouncement
 
-site.register(Announcement, AnnouncementIndex)
-site.register(ServiceAnnouncement, ServiceAnnouncementIndex)
